Community Justice Helsinki, Finland October 28th 2007 3R+F 28 players Matti Palomäki -- 4vp in the final Deck Name: pienempi paha(lainen) [lesser (d)evil] Third of the cards in the deck I never managed to play to any beneficial effect, but in most games the combination of having very aggressive grandpredator and a horde of guys on the table ended up making the actual contents of my library largely irrelevant. Crypt (12 cards, min=4, max=11, avg=1.83) ----------------------------------------- 1x Brooke 3 dom tha Tremere antitribu:2 1x Ember Wright 3 aus dom Tremere antitribu:3 1x Saiz 3 aus dom Tremere antitribu:3 1x Christine Boscacci 2 dom vic Pander:2 1x Heinrick Schlempt 2 tha Tremere antitribu:2 1x Jacob, The Glitch 2 THA Tremere antitribu:3 1x Ohanna 2 dom Malkavian:2 1x Angela Decker 1 pre Pander:2 1x Antoinette DuChamp 1 cel pre Caitiff:2 1x Huang, Blood Cultist 1 pro Pander:2 1x March Halcyon 1 for Pander:2 1x Royce 1 dom Pander:2 Library (90 cards) Master (14) 2x Archon Investigation 1x Barrens, The 2x Direct Intervention 2x Dreams of the Sphinx 1x Elder Library 2x Haven Uncovered 1x Information Highway 1x Mob Connections 1x Pentex(TM) Subversion 1x Powerbase: Zürich -- In the absence of intercept this was sickeningly good. Action (5) 2x Abbot -- I like these. Got smiled at until people realized I actually packed combat. 1x Aranthebes, The Immortal 1x Gramle -- This should help contesting Aranthebes, fetch another AI, or DI for a delayed vote. Never used though. 1x Graverobbing Ally (4) 4x Nephandus Action Modifier (5) 3x Conditioning 2x Leverage Reaction (12) 5x Deflection 2x Delaying Tactics 4x On the Qui Vive 1x Wake with Evening's Freshness Combat (50) 2x Botched Move -- Pushes the maximum damage in a round to 7. Cute, but nearly useless. :) 1x Boxed In 2x Fake Out 6x Glancing Blow 3x Lucky Blow 5x Pulled Fangs 2x Target Hand 5x Target Head -- I think none of these ever landed, 6x Target Vitals -- whereas none of these failed all day. 7x Taste of Vitae 2x Trap 6x Weighted Walking Stick 3x Zip Gun